@@ -26,7 +26,7 @@
 import os, traceback
 import json
 import yaml
-import cPiclke
+import cPickle
 from . import jsoncall
 import cherrypy
 from . import base
